@@ -251,7 +251,8 @@ class Api(object):
             auth=auth,
             headers=headers,
             params=params,
-            json=json_doc
+            json=json_doc,
+            verify=False
         )
         self.record_result(method, url, result)
         content = result['content']
